/**
 * Copyright (c) 2015-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.task.monit;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

/**
 * Base class for Ant task working with MONIT traces
 * 
 * @author Christophe DENEUX - Linagora
 */
public abstract class AbstractMonitAntTask extends Task {

    /**
     * Fail on error
     */
    protected boolean failOnError = true;

    /**
     * Do the task job
     *
     * @throws Exception
     */
    public abstract void doTask() throws Exception;

    @Override
    public final void execute() throws BuildException {

        try {
            this.doTask();
        } catch (final Exception e) {
            if (this.isFailOnError()) {
                if (e instanceof BuildException) {
                    throw (BuildException) e;
                } else {
                    throw new BuildException(e);
                }
            }
        }

    }

    /**
     * @return the failOnError
     */
    public boolean isFailOnError() {
        return this.failOnError;
    }

    /**
     * @param failOnError
     *            the failOnError to set
     */
    public void setFailOnError(final boolean failOnError) {
        this.failOnError = failOnError;
    }
}
