/**
 * Copyright (c) 2015-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.task.monit;

import org.ow2.petals.ant.task.monit.exception.BuildRefIdEmptyException;
import org.ow2.petals.ant.task.monit.exception.BuildRefIdMissingException;

/**
 * Base class for Ant task working with MONIT traces
 * 
 * @author Christophe DENEUX - Linagora
 */
public abstract class AbstractMonitAntTaskRequiringRefId extends AbstractMonitAntTask {

    /**
     * Name of the object reference in which flows have been put
     */
    protected String refId;

    /**
     * @param refId
     */
    public void setRefid(final String refId) {
        this.refId = refId;
    }

    @Override
    public final void doTask() throws Exception {

        if (this.refId == null) {
            throw new BuildRefIdMissingException(this.getLocation());
        }

        if (this.refId.isEmpty()) {
            throw new BuildRefIdEmptyException(this.getLocation());
        }

        final Object referencedObject = this.getProject().getReference(this.refId);
        this.doTaskRequiringRefId(referencedObject);
    }

    /**
     * Do the job of the task requiring 'refid'
     *
     * @param referencedObject
     * @throws Exception
     */
    public abstract void doTaskRequiringRefId(final Object referencedObject) throws Exception;
}
