/**
 * Copyright (c) 2015-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.task.monit;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import org.ow2.petals.ant.task.monit.exception.BuildRefIdInvalidException;
import org.ow2.petals.log.parser.api.model.Flow;
import org.ow2.petals.log.parser.api.model.FlowStep;

/**
 * Base class for Ant task working with MONIT traces
 * 
 * @author Christophe DENEUX - Linagora
 */
public abstract class AbstractMonitFlowsAntTaskRequiringRefId extends AbstractMonitAntTaskRequiringRefId {

    @Override
    public final void doTaskRequiringRefId(final Object referencedObject) throws Exception {

        if (referencedObject instanceof Set) {
            this.doTaskWithFlows((Set<Flow>) referencedObject);
        } else {
            throw new BuildRefIdInvalidException(this.getLocation());
        }
    }

    /**
     * Do the job of the task requiring 'refid' as a set of flows.
     *
     * @param flows
     * @throws Exception
     */
    public abstract void doTaskWithFlows(final Set<Flow> flows) throws Exception;

    /**
     * Build a flow step list ordered by arrival of the associated MONIT trace.
     * 
     * @param flowStep
     *            The root flow step from which the list must be build.
     * @return
     */
    protected List<FlowStep> getAllFlowSteps(final FlowStep flowStep) {
        final List<FlowStep> allFlowSteps = new ArrayList<>();
        allFlowSteps.add(flowStep);
        for (final FlowStep child : flowStep.getChildren()) {
            allFlowSteps.addAll(this.getAllFlowSteps(child));
        }
        return allFlowSteps;
    }
}
