/**
 * Copyright (c) 2015-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.task.monit.assertion.flowstep;

import java.util.ArrayList;
import java.util.List;

import org.ow2.petals.ant.task.monit.FlowStepInfo;

/**
 * Assertions to execute on a flow step
 * 
 * @author Christophe DENEUX - Linagora
 */
public class AssertFlowStep {

    /**
     * Assertions to execute on flow steps
     */
    private final List<AssertAttribute> attributeAssertions = new ArrayList<AssertAttribute>();

    /**
     * Flow step index on which attribute assertions must be applied
     */
    private Integer flowStepIdx = null;

    /**
     * Flag indicating how the flow step ends. If <code>true</code>, the flow step ends successfully, otherwise the flow
     * step fails.
     */
    private boolean endsWithError = false;

    /**
     * Information to extract from the selected flow step
     */
    private final List<FlowStepInfo> flowStepInfos = new ArrayList<FlowStepInfo>();

    public void addAttributeEquals(final AttributeEquals assertAttributeEquals) {
        this.attributeAssertions.add(assertAttributeEquals);
    }

    public void addAttributeSet(final AttributeSet assertAttributeSet) {
        this.attributeAssertions.add(assertAttributeSet);
    }

    public void setFlowStepIdx(final int flowStepIdx) {
        this.flowStepIdx = Integer.valueOf(flowStepIdx);
    }

    public void setEndsWithError(final boolean endsWithError) {
        this.endsWithError = endsWithError;
    }

    public void addFlowStepInfo(final FlowStepInfo flowStepInfo) {
        this.flowStepInfos.add(flowStepInfo);
    }

    public Integer getFlowStepIdx() {
        return this.flowStepIdx;
    }

    public boolean getEndsWithError() {
        return this.endsWithError;
    }

    public List<AssertAttribute> getAttributeAssertions() {
        return this.attributeAssertions;
    }

    public List<FlowStepInfo> getFlowStepInfos() {
        return this.flowStepInfos;
    }

}
