/**
 * Copyright (c) 2015-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.task.monit.assertion.flowstep;

import org.apache.tools.ant.Location;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.PropertyHelper;
import org.ow2.petals.ant.task.monit.assertion.flowstep.exception.BuildAssertAttributeFailException;
import org.ow2.petals.ant.task.monit.assertion.flowstep.exception.BuildAssertAttributeNameNotSetException;
import org.ow2.petals.ant.task.monit.assertion.flowstep.exception.BuildAssertAttributeNotFoundException;
import org.ow2.petals.ant.task.monit.assertion.flowstep.exception.BuildAssertEmptyAttributeValueException;
import org.ow2.petals.ant.task.monit.assertion.flowstep.exception.BuildAssertAttributeNotEqualsException;
import org.ow2.petals.log.parser.api.model.FlowStep;

/**
 * An attribute assertion checking that the value of the attribute equals a given value
 * 
 * @author Christophe DENEUX - Linagora
 *
 */
public class AttributeEquals extends AbstractAssertAttribute implements AssertAttribute {

    /**
     * The name of the attribute on which assertion will be done
     */
    private String name;

    /**
     * The value that the attribute must match
     */
    private String value;

    /**
     * Set the name of the attribute on which assertion will be done
     * 
     * @param name
     *            A flow step attribute name. Not <code>null</code>, not empty.
     */
    public void setName(final String name) {
        assert name != null;

        if (name.trim().isEmpty()) {
            throw new BuildAssertEmptyAttributeValueException(this.name);
        }

        this.name = name;
    }

    /**
     * Set the value that the attribute must match. The value is provided as nested text.
     * 
     * @param value
     *            A value. Not <code>null</code>, not empty.
     */
    public void setValue(final String value) {
        assert value != null;

        if (value.trim().isEmpty()) {
            throw new BuildAssertEmptyAttributeValueException(this.name);
        }

        this.value = value.trim();
    }

    @Override
    public void doAssert(final FlowStep flowStep, final Project project, final Location location)
            throws BuildAssertAttributeFailException {

        if (this.name == null) {
            throw new BuildAssertAttributeNameNotSetException(location);
        } else {
            final String resolvedValue = PropertyHelper.getPropertyHelper(project).replaceProperties(this.value);
            final String attrValue = (this.checkOnEndTrace ? flowStep.getOutcomeProperties() : flowStep
                    .getBeginProperties()).get(this.name);
            if (attrValue == null) {
                throw new BuildAssertAttributeNotFoundException(this.name, location);
            } else if (!attrValue.equals(resolvedValue)) {
                throw new BuildAssertAttributeNotEqualsException(this.name, this.value, resolvedValue, attrValue, location);
            }
        }
    }

}
