/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import java.net.URL;

import org.apache.tools.ant.BuildException;
import org.junit.Test;

/**
 * @author Nicolas Oddoux - EBM WebSourcing
 */
public class AbstractInstallerAntTaskTest {

    private class FileInstallerAntTask extends AbstractInstallerAntTask {

        public FileInstallerAntTask(final String file) {
            this.file = file;
        }

        @Override
        public void doTask() throws Exception {
            // NOP
        }

    }

    /**
     * Check {@link AbstractInstallerAntTask#validateFileParameter()} against a
     * file set to <code>null</code>.
     */
    @Test
    public void testValidateFileParameter_Null() {
        final FileInstallerAntTask fiat = new FileInstallerAntTask(null);

        try {
            fiat.validateFileParameter();
            fail("The exception '" + BuildException.class.getName() + "' is not thrown.");
        } catch (final BuildException e) {
            assertNotNull(e.getMessage());
            assertTrue(e.getMessage().contains("Missing attribute 'file'"));
        }

    }

    /**
     * Check {@link AbstractInstallerAntTask#validateFileParameter()} against an
     * empty file.
     */
    @Test    
    public void testValidateFileParameter_Empty() {
        final FileInstallerAntTask fiat = new FileInstallerAntTask("");

        try {
            fiat.validateFileParameter();
            fail("The exception '" + BuildException.class.getName() + "' is not thrown.");
        } catch (final BuildException e) {
            assertNotNull(e.getMessage());
            assertTrue(e.getMessage().contains("Empty attribute 'file'"));
        }

    }

    /**
     * Check {@link AbstractInstallerAntTask#validateFileParameter()} against an
     * invalid file.
     */
    @Test
    public void testValidateFileParameter_Invalid() {
        final String invalidFile = "/tmp/foo";
        final FileInstallerAntTask fiat = new FileInstallerAntTask(invalidFile);

        try {
            fiat.validateFileParameter();
            fail("The exception '" + BuildException.class.getName() + "' is not thrown.");
        } catch (final BuildException e) {
            assertNotNull(e.getMessage());
            assertTrue(e.getMessage().contains(invalidFile));
            assertTrue(e.getMessage().contains(
                    "is not a valid archive (zip or jar required)"));
        }

    }

    /**
     * Check {@link AbstractInstallerAntTask#validateFileParameter()} against an
     * JAR file.
     */
    @Test
    public void testValidateFileParameter_JAR() throws Exception {
        final FileInstallerAntTask fiat = new FileInstallerAntTask("/tmp/foo.jar");
        assertEquals(new URL("file:/tmp/foo.jar"),fiat.validateFileParameter());
    }

    /**
     * Check {@link AbstractInstallerAntTask#validateFileParameter()} against an
     * ZIP file.
     */
    @Test
    public void testValidateFileParameter_ZIP() throws Exception {
        final FileInstallerAntTask fiat = new FileInstallerAntTask("/tmp/foo.zip");
        assertEquals(new URL("file:/tmp/foo.zip"),fiat.validateFileParameter());
    }
}
