/**
 * Copyright (c) 2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.condition;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import javax.xml.namespace.QName;

import org.junit.Rule;
import org.junit.Test;
import org.ow2.petals.jmx.api.api.exception.NotRemoteJMXClientException;
import org.ow2.petals.jmx.api.mock.junit.EndpointMock;
import org.ow2.petals.jmx.api.mock.junit.PetalsJmxApiJunitRule;

/**
 * Unit tests of {@link HasEndpointDeployed}.
 * 
 * @author Christophe DENEUX - Linagora
 *
 */
public class HasEndpointDeployedTest {

    private static final String MY_NS = "http://my-itf.org/foo";

    private static final QName MY_ITF = new QName(MY_NS, "my-itf");

    private static final QName MY_SVC = new QName(MY_NS, "my-svc");

    private static final QName MY_UNKNOWN_SVC = new QName(MY_NS, "my-unknown-svc");

    private static final String MY_UNKNOWN_EP = "my-unknown-ep";

    private static final String MY_EP = "my-ep";

    @Rule
    public final PetalsJmxApiJunitRule jmxApi = new PetalsJmxApiJunitRule();

    @Test
    public void nominal() throws NotRemoteJMXClientException {

        final HasEndpointDeployed condition = new HasEndpointDeployed();
        condition.setHost(this.jmxApi.getHost().getHostName());
        condition.setPort(this.jmxApi.getPort());
        condition.setUsername(this.jmxApi.getUsername());
        condition.setPassword(this.jmxApi.getPassword());

        condition.setInterfaceName(MY_ITF.toString());
        assertFalse(condition.eval());
        
        this.jmxApi.registerEndpoint(new EndpointMock(new QName[] { MY_ITF }, MY_SVC, MY_EP));
        assertTrue(condition.eval());

        condition.setServiceName(MY_UNKNOWN_SVC.toString());
        assertFalse(condition.eval());

        condition.setServiceName(MY_SVC.toString());
        assertTrue(condition.eval());

        condition.setEndpointName(MY_UNKNOWN_EP);
        assertFalse(condition.eval());

        condition.setEndpointName(MY_EP);
        assertTrue(condition.eval());

        condition.setServiceName(null);
        assertTrue(condition.eval());

        condition.setInterfaceName(null);
        assertTrue(condition.eval());

        this.jmxApi.registerEndpoint(new EndpointMock(new QName[] { MY_ITF }, MY_SVC, MY_UNKNOWN_EP));

        condition.setEndpointName(MY_EP);
        assertTrue(condition.eval());

        condition.setExpectedNumber(2);
        assertFalse(condition.eval());

        condition.setInterfaceName(MY_ITF.toString());
        condition.setEndpointName(null);
        assertTrue(condition.eval());
    }

}
