/**
 * Copyright (c) 2015-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.task.monit.assertion.flowtree;

import static org.junit.Assert.fail;

import java.net.URISyntaxException;

import org.apache.tools.ant.Project;
import org.junit.Test;
import org.ow2.petals.ant.task.monit.assertion.flowtree.exception.BuildAssertFlowTreesSizeException;
import org.ow2.petals.ant.task.monit.assertion.flowtree.exception.BuildAssertNoAssertionException;
import org.ow2.petals.ant.task.monit.exception.BuildRefIdInvalidException;

/**
 * Unit tests of {@link AssertFlowTreesTask}. Unit tests of nested assertions are in package
 * <code>org.ow2.petals.ant.task.monit.assertion</code>.
 * 
 * @author Christophe DENEUX - Linagora
 *
 */
public class AssertFlowTreesTaskTest extends AbstractAssertFlowTreesTest {

    /**
     * Check assertions on the number of flow trees build from MONIT traces under nominal conditions
     */
    @Test
    public void nominal() throws URISyntaxException {

        final Project project = this.buildFlowTrees();

        final AssertFlowTreesTask taskWithTheRightExpectedValue = new AssertFlowTreesTask();
        taskWithTheRightExpectedValue.setRefid(REF_TREE_ID);
        taskWithTheRightExpectedValue.setAssertSize(7); // 4 for BC Gateway + 3 for SE Activiti
        taskWithTheRightExpectedValue.setProject(project);
        taskWithTheRightExpectedValue.execute();

        final AssertFlowTreesTask taskWithNotTheRightExpectedValue = new AssertFlowTreesTask();
        taskWithNotTheRightExpectedValue.setRefid(REF_TREE_ID);
        taskWithNotTheRightExpectedValue.setAssertSize(1000);
        taskWithNotTheRightExpectedValue.setProject(project);
        try {
            taskWithNotTheRightExpectedValue.execute();
            fail("BuildAssertFlowTreesSizeException not thrown");
        } catch (final BuildAssertFlowTreesSizeException e) {
            // NOP: expected exception
        }
    }

    /**
     * Check assertions on flow trees where no assertion is defined
     */
    @Test(expected = BuildAssertNoAssertionException.class)
    public void noAssertionDefined() throws URISyntaxException {

        final Project project = this.buildFlowTrees();

        final AssertFlowTreesTask task = new AssertFlowTreesTask();
        task.setRefid(REF_ID);
        task.setProject(project);

        task.execute();

    }

    /**
     * Check assertions on flow trees where the ref-id is not as expected
     */
    @Test(expected = BuildRefIdInvalidException.class)
    public void refIdNotAsExpected() throws URISyntaxException {

        final Project project = new Project();
        project.addReference(REF_ID, new Object());

        final AssertFlowTreesTask task = new AssertFlowTreesTask();
        task.setRefid(REF_ID);
        task.setProject(project);

        task.execute();

    }
}
